"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const tsHandler_1 = require("../tsHandler");
const suppressTsErrors_1 = require("../../lib/suppressTsErrors");
const ts_morph_1 = require("ts-morph");
const replaceWithTextMock = vitest_1.vi.fn();
const saveSyncMock = vitest_1.vi.fn();
const getSourceFilesMock = vitest_1.vi.fn(() => [
    {
        replaceWithText: replaceWithTextMock,
        saveSync: saveSyncMock,
    },
]);
const mockText = `
  @ts-expect-error TS2322
  const a: string = 1;
`;
vitest_1.vi.mock("ts-morph", () => {
    return {
        Project: vitest_1.vi.fn(() => ({
            getSourceFiles: getSourceFilesMock,
        })),
    };
});
vitest_1.vi.mock("../../lib/suppressTsErrors", () => {
    return {
        suppressTsErrors: vitest_1.vi.fn(() => ({
            text: mockText,
            count: 1,
        })),
    };
});
(0, vitest_1.describe)("tsHandler", () => {
    (0, vitest_1.afterEach)(() => {
        vitest_1.vi.restoreAllMocks();
    });
    (0, vitest_1.it)("execute process", () => {
        const tsconfigPath = "./tsconfig.json";
        const commentType = 1;
        const errorCode = true;
        const count = (0, tsHandler_1.tsHandler)({
            tsconfigPath,
            commentType,
            errorCode,
        });
        (0, vitest_1.expect)(ts_morph_1.Project).toHaveBeenCalledWith({
            tsConfigFilePath: tsconfigPath,
        });
        (0, vitest_1.expect)(suppressTsErrors_1.suppressTsErrors).toHaveBeenCalledTimes(1);
        (0, vitest_1.expect)(getSourceFilesMock).toHaveBeenCalledTimes(1);
        (0, vitest_1.expect)(replaceWithTextMock).toHaveBeenCalledWith(mockText);
        (0, vitest_1.expect)(saveSyncMock).toHaveBeenCalledTimes(1);
        (0, vitest_1.expect)(count).toBe(1);
    });
});
