"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const vueHandler_1 = require("../vueHandler");
const suppressTsErrors_1 = require("../../lib/suppressTsErrors");
const ts_morph_1 = require("ts-morph");
const promises_1 = require("fs/promises");
const sourceFileMock = {};
const mockFilePath = "src/example.vue";
const createSourceFileMock = vitest_1.vi.fn(() => sourceFileMock);
const mockPrevText = `
<template>
  <div>test</div>
</template>
<script lang="ts">
  const a: string = 1;
</script>
`;
const mockNewText = `
<template>
  <div>test</div>
</template>
<script lang="ts">
  @ts-expect-error TS2322
  const a: string = 1;
</script>
`;
const mockPrevScript = `
  const a: string = 1;
`;
const mockNewScript = `
  @ts-expect-error TS2322
  const a: string = 1;
`;
vitest_1.vi.mock("ts-morph", () => {
    return {
        Project: vitest_1.vi.fn(() => ({
            createSourceFile: createSourceFileMock,
        })),
    };
});
vitest_1.vi.mock("../../lib/suppressTsErrors", () => {
    return {
        suppressTsErrors: vitest_1.vi.fn(() => ({
            text: mockNewScript,
            count: 1,
        })),
    };
});
vitest_1.vi.mock("glob", () => {
    return {
        default: {
            sync: vitest_1.vi.fn(() => [mockFilePath]),
        },
    };
});
vitest_1.vi.mock("fs/promises", () => {
    return {
        readFile: vitest_1.vi.fn(() => Promise.resolve(mockPrevText)),
        writeFile: vitest_1.vi.fn(() => Promise.resolve()),
    };
});
vitest_1.vi.mock("../../lib/extractTypeScriptFromVue", () => {
    return {
        extractTypeScriptFromVue: vitest_1.vi.fn(() => mockPrevScript),
    };
});
(0, vitest_1.describe)("vueHandler", () => {
    (0, vitest_1.afterEach)(() => {
        vitest_1.vi.restoreAllMocks();
    });
    (0, vitest_1.it)("execute process", async () => {
        const tsconfigPath = "./tsconfig.json";
        const commentType = 1;
        const errorCode = true;
        const targetPathPattern = "src/**/*.vue";
        const count = await (0, vueHandler_1.vueHandler)({
            tsconfigPath,
            commentType,
            errorCode,
            targetPathPattern,
        });
        (0, vitest_1.expect)(promises_1.readFile).toHaveBeenCalledWith(mockFilePath, "utf8");
        (0, vitest_1.expect)(ts_morph_1.Project).toHaveBeenCalledWith({
            tsConfigFilePath: tsconfigPath,
        });
        (0, vitest_1.expect)(createSourceFileMock).toHaveBeenCalledWith(`${mockFilePath}.ts`, mockPrevScript);
        (0, vitest_1.expect)(suppressTsErrors_1.suppressTsErrors).toHaveBeenCalledWith({
            sourceFile: sourceFileMock,
            commentType,
            withErrorCode: errorCode,
        });
        (0, vitest_1.expect)(promises_1.writeFile).toHaveBeenCalledWith(mockFilePath, mockNewText);
        (0, vitest_1.expect)(count).toBe(1);
    });
});
