"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.vueProcessing = void 0;
const glob = __importStar(require("glob"));
const promises_1 = require("fs/promises");
const extractTypeScriptFromVue_1 = require("./extractTypeScriptFromVue");
const suppressTsErrors_1 = require("./suppressTsErrors");
const vueProcessing = async (path, project) => {
    // extract script from vue files
    const filePaths = glob.sync(path);
    const allScripts = await Promise.all(filePaths.map(async (path) => {
        const source = await (0, promises_1.readFile)(path, "utf8");
        const scriptSource = (0, extractTypeScriptFromVue_1.extractTypeScriptFromVue)(source);
        return {
            filePath: path,
            source: scriptSource,
        };
    }));
    // create script with inserted comment
    let commentCount = 0;
    const scriptsWithComment = allScripts
        .filter((script) => script.source !== null)
        .map((script) => {
        // add script to program
        const sourceFile = project.createSourceFile(`${script.filePath}.ts`, script.source);
        // add comment to source
        const { text, count } = (0, suppressTsErrors_1.suppressTsErrors)({
            sourceFile,
            commentType: 1,
            withErrorCode: true,
        });
        commentCount += count;
        return {
            ...script,
            newSource: text,
        };
    });
    // rewrite vue files
    await Promise.all([
        scriptsWithComment.map(async (script) => {
            const currentSource = await (0, promises_1.readFile)(script.filePath, "utf8");
            const newSource = currentSource.replace(script.source, script.newSource);
            await (0, promises_1.writeFile)(script.filePath, newSource);
        }),
    ]);
    console.log("Done 🎉");
    console.log(`suppress errors: ${commentCount}`);
};
exports.vueProcessing = vueProcessing;
